<?php
/**
 * Amount Left for Free Shipping for WooCommerce - General Section Settings
 *
 * @version 1.6.0
 * @since   1.0.0
 * @author  Algoritmika Ltd.
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! class_exists( 'Alg_WC_Left_To_Free_Shipping_Settings_General' ) ) :

class Alg_WC_Left_To_Free_Shipping_Settings_General extends Alg_WC_Left_To_Free_Shipping_Settings_Section {

	/**
	 * Constructor.
	 *
	 * @version 1.3.0
	 * @since   1.0.0
	 */
	function __construct() {
		$this->id   = '';
		$this->desc = __( 'General', 'amount-left-free-shipping-woocommerce' );
		parent::__construct();
	}

	/**
	 * get_settings.
	 *
	 * @version 1.6.0
	 * @since   1.0.0
	 * @todo    [dev] (next) `alg_wc_left_to_free_shipping_ajax_pass_min_amount`: remove option (or at least default to `no`?)
	 * @todo    [dev] (next) `alg_wc_left_to_free_shipping_check_free_shipping`: default to `yes`
	 * @todo    [dev] (next) `alg_wc_left_to_free_shipping_check_virtual`: default to `yes`
	 * @todo    [dev] (next) `alg_wc_left_to_free_shipping_ajax_enabled`: better description
	 */
	function get_settings() {

		$general_settings = array(
			array(
				'title'    => __( 'General Options', 'amount-left-free-shipping-woocommerce' ),
				'type'     => 'title',
				'id'       => 'alg_wc_left_to_free_shipping_general_options',
			),
			array(
				'title'    => __( 'Amount Left for Free Shipping', 'amount-left-free-shipping-woocommerce' ),
				'desc'     => '<strong>' . __( 'Enable plugin', 'amount-left-free-shipping-woocommerce' ) . '</strong>',
				'id'       => 'alg_wc_left_to_free_shipping_enabled',
				'default'  => 'yes',
				'type'     => 'checkbox',
			),
			array(
				'title'    => __( 'Include discounts', 'amount-left-free-shipping-woocommerce' ),
				'desc'     => __( 'Include', 'amount-left-free-shipping-woocommerce' ),
				'desc_tip' => __( 'Include discounts when calculating cart total.', 'amount-left-free-shipping-woocommerce' ),
				'id'       => 'alg_wc_left_to_free_shipping_include_discounts',
				'default'  => 'yes',
				'type'     => 'checkbox',
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_left_to_free_shipping_general_options',
			),
		);

		$free_shipping_reached_settings = array(
			array(
				'title'    => __( '"Free Shipping Reached" Options', 'amount-left-free-shipping-woocommerce' ),
				'type'     => 'title',
				'id'       => 'alg_wc_left_to_free_shipping_reached_options',
				'desc'     => __( 'Outputted when min free shipping amount is reached.', 'amount-left-free-shipping-woocommerce' ),
			),
			array(
				'title'    => __( 'Message on free shipping reached', 'amount-left-free-shipping-woocommerce' ),
				'desc_tip' => __( 'You can use HTML and/or shortcodes here.', 'amount-left-free-shipping-woocommerce' ) . ' ' .
					__( 'To disable - set it empty.', 'amount-left-free-shipping-woocommerce' ),
				'id'       => 'alg_wc_left_to_free_shipping_info_content_reached',
				'default'  => __( 'You have free delivery!', 'amount-left-free-shipping-woocommerce' ),
				'type'     => 'textarea',
				'css'      => 'width:100%;height:100px;',
				'alg_wc_alfs_raw' => true,
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_left_to_free_shipping_reached_options',
			),
		);

		$ajax_settings = array(
			array(
				'title'    => __( 'AJAX Options', 'amount-left-free-shipping-woocommerce' ),
				'desc'     => __( 'Enable this section if you want the amount to be updated via AJAX, e.g. when using plugin\'s "Store notice" section, or WooCommerce "Enable AJAX add to cart buttons on archives" option, or for some positions in cart, when customer updates items quantities and the amount text is positioned outside of automatically refreshed area.', 'amount-left-free-shipping-woocommerce' ),
				'type'     => 'title',
				'id'       => 'alg_wc_left_to_free_shipping_ajax_options',
			),
			array(
				'title'    => __( 'Enable AJAX', 'amount-left-free-shipping-woocommerce' ),
				'desc'     => __( 'Enable', 'amount-left-free-shipping-woocommerce' ),
				'type'     => 'checkbox',
				'id'       => 'alg_wc_left_to_free_shipping_ajax_enabled',
				'default'  => 'no',
				'desc_tip' => apply_filters( 'alg_wc_left_to_free_shipping_settings', $this->pro_desc ),
				'custom_attributes' => apply_filters( 'alg_wc_left_to_free_shipping_settings', array( 'disabled' => 'disabled' ) ),
			),
			array(
				'title'    => __( 'Events', 'amount-left-free-shipping-woocommerce' ),
				'desc_tip' => __( 'JavaScript events to update the amount text on. Leave the default value if unsure.', 'amount-left-free-shipping-woocommerce' ),
				'desc'     => sprintf( __( 'Default value: %s', 'amount-left-free-shipping-woocommerce' ),
					'<code>updated_cart_totals added_to_cart removed_from_cart wc_fragment_refresh updated_checkout</code>' ),
				'type'     => 'text',
				'id'       => 'alg_wc_left_to_free_shipping_ajax_events',
				'default'  => 'updated_cart_totals added_to_cart removed_from_cart wc_fragment_refresh updated_checkout',
				'css'      => 'width:100%;',
			),
			array(
				'title'    => __( 'Pass min amount', 'amount-left-free-shipping-woocommerce' ),
				'desc_tip' => __( 'Passes min amount via HTML attribute.', 'amount-left-free-shipping-woocommerce' ),
				'desc'     => __( 'Pass', 'amount-left-free-shipping-woocommerce' ),
				'type'     => 'checkbox',
				'id'       => 'alg_wc_left_to_free_shipping_ajax_pass_min_amount',
				'default'  => 'yes',
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_left_to_free_shipping_ajax_options',
			),
		);

		$user_roles = $this->get_user_roles();
		$advanced_mma_settings = array(
			array(
				'title'    => __( 'Advanced: Manual Min Amount', 'amount-left-free-shipping-woocommerce' ),
				'type'     => 'title',
				'id'       => 'alg_wc_left_to_free_shipping_advanced_mma_options',
				'desc'     => __( 'Generally the plugin will retrieve the minimum free shipping order amount automatically, however, if you are using non-standard shipping methods for free shipping, you need to set the amount manually here.', 'amount-left-free-shipping-woocommerce' ),
			),
			array(
				'title'    => __( 'Manual min amount', 'amount-left-free-shipping-woocommerce' ),
				'desc_tip' => __( 'Ignored if set to zero.', 'amount-left-free-shipping-woocommerce' ),
				'id'       => 'alg_wc_left_to_free_shipping_manual_min_amount',
				'default'  => 0,
				'type'     => 'number',
				'custom_attributes' => array( 'min' => 0, 'step' => 0.000001 ),
			),
			array(
				'desc'     => __( 'User roles', 'amount-left-free-shipping-woocommerce' ),
				'desc_tip' => __( 'Select user roles for which you want to set individual manual min amounts.', 'amount-left-free-shipping-woocommerce' ) . ' ' .
					__( 'Save changes for new option fields.', 'amount-left-free-shipping-woocommerce' ),
				'id'       => 'alg_wc_left_to_free_shipping_mma_roles',
				'default'  => array(),
				'type'     => 'multiselect',
				'class'    => 'chosen_select',
				'options'  => $user_roles,
			),
		);
		$min_amount_user_roles = get_option( 'alg_wc_left_to_free_shipping_mma_roles', array() );
		foreach ( $min_amount_user_roles as $user_role ) {
			$advanced_mma_settings = array_merge( $advanced_mma_settings, array(
				array(
					'desc'     => ( isset( $user_roles[ $user_role ] ) ? $user_roles[ $user_role ] : $user_role ),
					'desc_tip' => __( 'Ignored if set to zero.', 'amount-left-free-shipping-woocommerce' ),
					'id'       => "alg_wc_left_to_free_shipping_mma_roles_val[{$user_role}]",
					'default'  => 0,
					'type'     => 'number',
					'custom_attributes' => array( 'min' => 0, 'step' => 0.000001 ),
				),
			) );
		}
		$advanced_mma_settings = array_merge( $advanced_mma_settings, array(
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_left_to_free_shipping_advanced_mma_options',
			),
		) );

		$advanced_settings = array(
			array(
				'title'    => __( 'Advanced Options', 'amount-left-free-shipping-woocommerce' ),
				'type'     => 'title',
				'id'       => 'alg_wc_left_to_free_shipping_advanced_options',
			),
			array(
				'title'    => __( 'Check for free shipping', 'amount-left-free-shipping-woocommerce' ),
				'desc'     => __( 'Enable', 'amount-left-free-shipping-woocommerce' ),
				'desc_tip' => __( 'Check for already available alternative (i.e. not requiring minimum order amount) free shipping methods.', 'amount-left-free-shipping-woocommerce' ) . ' ' .
					__( 'No text will be outputted in this case.', 'amount-left-free-shipping-woocommerce' ),
				'id'       => 'alg_wc_left_to_free_shipping_check_free_shipping',
				'default'  => 'no',
				'type'     => 'checkbox',
			),
			array(
				'title'    => __( 'Check for virtual cart', 'amount-left-free-shipping-woocommerce' ),
				'desc'     => __( 'Enable', 'amount-left-free-shipping-woocommerce' ),
				'desc_tip' => __( 'Check if cart consists of virtual products only.', 'amount-left-free-shipping-woocommerce' ) . ' ' .
					__( 'No text will be outputted in this case.', 'amount-left-free-shipping-woocommerce' ),
				'id'       => 'alg_wc_left_to_free_shipping_check_virtual',
				'default'  => 'no',
				'type'     => 'checkbox',
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_left_to_free_shipping_advanced_options',
			),
		);

		$info = array(
			array(
				'title'    => __( 'Info', 'amount-left-free-shipping-woocommerce' ),
				'type'     => 'title',
				'id'       => 'alg_wc_left_to_free_shipping_info',
				'desc'     => '<div style="background-color:white;color:black;padding:10px;">' .
					'<strong>' . __( 'You can also use:', 'amount-left-free-shipping-woocommerce' ) . '</strong>' .
					'<ol>' .
						'<li>' .
								'<span style="text-decoration:underline;">' . __( 'Widget', 'amount-left-free-shipping-woocommerce' ) . '</span>' . ': ' .
								'<em>' . __( 'Amount Left for Free Shipping', 'amount-left-free-shipping-woocommerce' ) . '</em>' .
						'</li>' .
						'<li>' .
								'<span style="text-decoration:underline;">' . __( 'Shortcode', 'amount-left-free-shipping-woocommerce' ) . '</span>' . ': ' .
								'<code>[alg_wc_left_to_free_shipping content="%amount_left_for_free_shipping% left for free shipping"]</code>' .
						'</li>' .
						'<li>' .
								'<span style="text-decoration:underline;">' . __( 'PHP function', 'amount-left-free-shipping-woocommerce' ) . '</span>' . ': ' .
								'<code>echo alg_wc_get_left_to_free_shipping( "%amount_left_for_free_shipping% left for free shipping" );</code>' .
						'</li>' .
					'</ol>' .
				'</div>',
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_left_to_free_shipping_info',
			),
		);

		return array_merge( $general_settings, $free_shipping_reached_settings, $ajax_settings, $advanced_mma_settings, $advanced_settings, $info );
	}

}

endif;

return new Alg_WC_Left_To_Free_Shipping_Settings_General();
